@@ -1,6 +1,6 @@
  /*****************************************************************************
  **  This is part of the SpaceZero program
- **  Copyleft (C) 2006-2011  M.Revenga
+ **  Copyright (C) 2006-2013  MRevenga
  **
  **  This program is free software; you can redistribute it and/or modify
  **  it under the terms of the GNU General Public License (version 3), or
@@ -17,11 +17,11 @@
  **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  ******************************************************************************/
 
-/*************  SpaceZero  M.R.H. 2006-2011 ******************
-		Author: M.Revenga
+/*************  SpaceZero  M.R.H. 2006-2013 ******************
+		Author: MRevenga
 		E-mail: mrevenga at users.sourceforge.net
-		version 0.80 May 2011
-****/
+		version 0.86 December 2013
+**************************************************************/
 
 #ifndef _OBJECTS_
 #define _OBJECTS_
@@ -33,6 +33,8 @@
 #include <gtk/gtk.h>
 #include "general.h"
 #include "data.h"
+#include "players.h"
+
 
 
 #define VELMAX 60
@@ -51,9 +53,10 @@
 /* Obj modes */
 #define NAV 1
 #define LANDED 2
+#define SOLD 3
 
 
-/* object types */
+/* object types 0-31 */
 #define SHIP 1
 #define PROJECTILE 2
 #define PLANET 3
@@ -63,34 +66,24 @@
 #define TRACE 14
 #define ALLOBJS 31
 
-/* objects subtypes */
+/* objects subtypes 0-16*/
 /* ship subtypes (SHIP)*/
-#define SHIP0 0
+#define SHIP0 0  /* no ship, any ship */
 #define SHIP1 1
 #define SHIP2 2
 #define SHIP3 3
 #define SHIP4 4
 #define SHIP5 5
 #define SHIP6 6
-#define SHIPMAX SHIP6
+#define SHIP7 7
+#define SHIP8 8
+#define SHIP9 9
+#define SHIP_S_MAX SHIP9
 
-#define PRICESHIP0 100
-#define PRICESHIP1 100
-#define PRICESHIP2 200
-#define PRICESHIP3 300
-#define PRICESHIP4 400
-#define PRICESHIP5 200
-#define PRICESHIP6 200
-
-/* projectile subtypes (PROJECTILE)*/
-#define SHOT0 20
-#define SHOT1 21
-#define SHOT2 22
-#define SHOT3 23  /* missile */
-#define SHOT4 24  /* laser */
-#define EXPLOSION 25
-#define MISSILE SHOT3
-#define LASER SHOT4
+/* Asteroid subtypes */
+#define ASTEROID1 1
+#define ASTEROID2 2
+#define ASTEROID3 3
 
 
 
@@ -100,17 +93,81 @@
 #define QUEEN SHIP4
 #define SATELLITE SHIP5
 #define TOWER SHIP6
+#define PILOT SHIP7
+#define FREIGHTER SHIP8
+#define GOODS SHIP9
+
+/* cost of the spaceships */
+
+#define COSTEXPLORER 0.01
+#define COSTFIGHTER 0.01
+#define COSTQUEEN 0.04
+#define COSTFREIGHTER 0.04
+#define COSTGOODS 0.0
+#define COSTSATELLITE 0.005
+#define COSTTOWER 0.0
+#define COSTPILOT 0.0
+
+
+#define PRICESHIP0 0
+#define PRICESHIP1 100
+#define PRICESHIP2 200
+#define PRICESHIP3 300
+#define PRICESHIP4 400
+#define PRICESHIP5 50
+#define PRICESHIP6 200
+#define PRICESHIP7 50
+#define PRICESHIP8 5000
+#define PRICESHIP9 0
+
+/* mass of ships */
+#define MASSEXPLORER 50
+#define MASSFIGHTER 100
+#define MASSQUEEN 400
+#define MASSSATELLITE 10
+#define MASSTOWER 100
+#define MASSPILOT 10
+#define MASSFREIGHTER 400
+#define MASSGOODS 10
+
+
+/* projectile subtypes (PROJECTILE) 49-64*/
+#define SHOT0 49
+#define SHOT1 50
+#define SHOT2 51
+#define SHOT3 52  /* missile */
+#define SHOT4 53  /* laser */
+#define EXPLOSION 54
+#define MISSILE SHOT3
+#define LASER SHOT4
+
+
+/* objects life */
+
+#define LIFEPILOT 5000
+#define LIFEGOODS 2500 
+#define LIFESATELLITE 2400
+#define LIFEASTEROID 9000
+#define LIFEEXPLOSION 150
+#define LIFETRACE 500
+#define LIFESHOT1 30
+#define LIFESHOT2 50
+#define LIFESHOT3 200 /* MISSILE */
+#define LIFESHOT4 5   /* LASER */
+
+/* ship items */
+#define ITSURVIVAL 1  /* has a survival pod */ 
 
 
 /* weapons types */
 #define CANNON0 0   /* no weapon */
-#define CANNON1 1
-#define CANNON2 2
-#define CANNON3 3
-#define CANNON4 4
-#define CANNON5 5
-#define CANNON6 6
-#define CANNON7 7   /* velocity  */
+#define CANNON1 1   /* shot */
+#define CANNON2 2   /* shot */
+#define CANNON3 3   /* shot */
+#define CANNON4 4   /* tower,new precision cannon */
+#define CANNON5 5   /* shot */
+#define CANNON6 6   /* shot */
+#define CANNON7 7   /* velocity, not used  */
 #define CANNON8 8   /* missile */
 #define CANNON9 9   /* laser */
 #define NUMWEAPONS 10
@@ -134,7 +191,8 @@
 #define ENGINE3 3
 #define ENGINE4 4
 #define ENGINE5 5
-#define ENGINEMAX ENGINE5
+#define ENGINE6 6
+#define ENGINEMAX ENGINE6
 
 #define PRICEENGINE0 0
 #define PRICEENGINE1 100
@@ -142,33 +200,26 @@
 #define PRICEENGINE3 300
 #define PRICEENGINE4 400
 #define PRICEENGINE5 500
+#define PRICEENGINE6 600
 
 /* Planet states */
-#define POWN 1
-#define PALLY 2
-#define PINEXPLORE 3
-#define PENEMY 4
-#define PUNKNOWN 5
+#define PUNKNOWN   0
+#define POWN       1
+#define PALLY      1<<1
+#define PINEXPLORE 1<<2
+#define PENEMY     1<<3
+
 
 /* Terrain types */
 #define TERRAIN 0
 #define LANDZONE 1
 
-
-#define ASTEROID1 1
-#define ASTEROID2 2
-#define ASTEROID3 3
-
-/* TODO ai players profiles */
-#define PLAYERPROFDEFAULT 0   /* attack planets default profile*/
-#define PLAYERPROFPACIFIST 1  /* never attack planets */
-#define PLAYERPROFAGRESSIVE 2 /* */
-
-/* ai players strategies */
-#define NUMPLAYERSTRAT 3
-#define PLAYERSTRATDEFAULT 0 /* attack near from near planet*/
-#define PLAYERSTRATRANDOM 1  /* choose a random planet to attack */
-#define PLAYERSTRATSTRONG 2  /* from strongest to nearest */
+/* player status */
+#define PLAYERNULL 0       /* not used */
+#define PLAYERIDLE 1       /* not used */
+#define PLAYERDEAD 2       /* GAMEOVER */
+#define PLAYERACTIVE 3     /* all states > PLAYERACTIVE are active states */
+#define PLAYERMODIFIED 4   /* when the number of ships or habitat change */  
 
 #define OBJNAMESMAXLEN 16  /*max size of objs names. */
 
@@ -180,9 +231,6 @@ struct _Segment{
 
 typedef struct _Segment Segment;
 
-struct Tabla{
-  int id,parent,dest,in,planet;
-};
 
 struct Planet{
   Segment *segment;  /* Planet terrain */
@@ -191,25 +239,21 @@ struct Planet{
   float gold;        /* (0,...] */
   float reggold;     /* index of gold regeneration */
   float A,B;         /* local, tmp variables */
-
 };
 
+typedef struct _Object Object;
 
-struct Order{
-  int priority;
-  int id;
-  int time;       /* duration of the order */
-  int g_time;    /* moment of the order */
-  float a,b,c,d;
-  float e,f,g,h;
-  /*  struct Order *next; */
-};
+struct ObjList{ 
+  Object *obj; 
+  struct ObjList *next; 
+}; 
 
+struct HeadObjList{ 
+  int n; 
+  int update; 
+  struct ObjList *list; 
+}; 
 
-struct ListOrder{
-  struct Order order;
-  struct ListOrder *next;
-};
 
 typedef struct{
   int type;
@@ -225,7 +269,7 @@ typedef struct{
 typedef struct{
   int type;
   int rate;       /* time the weapon is ready again */
-  int nshots;     /* number of shots */
+  int nshots;     /* number of shots, guns */
   int cont1;      /* if !=0 cant shot again */ 
   int mass;       /* mass of the projectile */
   int n;          /* number of ammunition */
@@ -247,28 +291,55 @@ typedef struct{
 }Engine;
 
 typedef struct{
-  struct _Object *obj[4]; /* use to point to 4 objects 
+  Object *obj[4]; /* use to point to 4 objects 
 			     enemy ship, 
 			     planets: enemy, inexplore and ally  */
   float d2[4];   /* distance2 to these objects */
   int td2[4];    /* time when such info is updated */
   int mlevel;    /* if there is a near high level SHIP */
   int tmlevel;
-  int a,b;         /* low fuel stop switch */
+  int a,b;         /* low fuel stop switches */
 }Data;
 
 
+typedef struct{
+  int capacity;                  /* max. mass capacity */
+  int mass;                      /* actual mass cargo */
+  int n;                         /* number of objects */ 
+  struct HeadObjList *hlist;     /* objects list */
+}Cargo;
+
+struct Order{
+  int priority;
+  int id;
+  int time;       /* duration of the order */
+  int g_time;     /* order time */
+  float a,b,c,d;  /* internal variables */
+  float e,f,g,h;
+  float i,j,k,l;
+};
+
+
+struct OrderList{
+  struct Order order;
+  struct OrderList *next;
+};
+
+
 struct _Object{
   int id;           /* global identifier */
   int pid;          /* player identifier */
-  char name[OBJNAMESMAXLEN];   /* object name */
-  short player;
+  int oriid,destid; /* origin and destination planet id (only FREIGHTER) */
+  char name[MAXTEXTLEN];   /* object name */
+  short player;     /* id of the player */
   short type;       /* type: SHIP,PLANET,PROJECTILE,... */
 
   short subtype;    /* object subtype */
   short level;
-  float experience;
-  int kills;        /*number of enemies killed */
+  float experience; /* experience */
+  float pexperience;/* partial experience */
+  int kills;        /*number of enemies killed. */
+  int ntravels;        /*number of planets landed. */
 
   int durable;
   int visible;      /* not used */
@@ -276,16 +347,16 @@ struct _Object{
   int radar;        /* radar range */
   int mass;         /* mass */
 
-  int cargo;        /* capacity of the bodega TODO*/
+  int items;        /* survival ship, ...*/
   int radio;        /* ship radio */
   float cost;       /* cost of the object per unit time*/
   int damage;       /* damage of the ship in collision*/
 
-  short ai;         /* -1: by keyboard. [0,10] */
+  short ai;         /* 0: (manual).(1,10) with AI [0,10] */
   short modified;   /* SENDOBJMOD, SENDOBJMOD0, etc, must be updated by net */
-  short ttl;        /* if !=0 dont send  */
+  short ttl;        /* if !=0 don't send  */
   short habitat;    /* free space or planet (H_SPACE H_PLANET)*/
-  short mode;       /* LANDED, NAV(EGATING)  */
+  short mode;       /* LANDED, NAV(EGATING), SOLD */
 
   float x,y;        /* position */
   float x0,y0;      /* old position */  
@@ -307,27 +378,31 @@ struct _Object{
   int sw;
   short trace;
   int norder;       /* number of pending orders */
+  Cargo cargo;        /* capacity of the bodega TODO. In planets: no of ships */
+
   struct Order actorder;
-  struct _Object *parent;     /* pointer to parent obj */
-  struct _Object *dest;       /* pointer to nearest enemy object */
-  struct _Object *in;         /* Object in which is contained */ 
+  Object *parent;     /* pointer to parent obj */
+  Object *dest;       /* pointer to nearest enemy object */
+  Object *in;         /* Object in which is contained */ 
   struct Planet *planet;
-  struct ListOrder *lorder;
+  struct OrderList *lorder;
 
-  Weapon *weapon;     /*weapon selected 0 1 2*/
-  Weapon weapon0;     /* actual weapon */
-  Weapon weapon1;     /* actual weapon */
-  Weapon weapon2;     /* actual weapon */
+  Weapon *weapon;     /* weapon selected 0 1 2*/
+  Weapon weapon0;     /* shots */
+  Weapon weapon1;     /* missile */
+  Weapon weapon2;     /* laser beam */
   Engine engine;      /* motor */
-  Data *cdata;         /* data base */
+  Data *cdata;        /* data base */
+
 };
-typedef struct _Object Object;
 
 
-struct ObjectAll{ /* SENDOBJALL */
+
+struct ObjectAll{   /* SENDOBJALL */
   int id;           /* global identifier */
   int pid;          /* player identifier */
-  char name[OBJNAMESMAXLEN];   /* object name */
+  int oriid,destid; /* origin and destination planet id (only FREIGHTER) */
+  char name[MAXTEXTLEN];   /* object name */
   short player;
   short type;       /* type: SHIP,PLANET,PROJECTILE,... */
   short subtype;    /* object subtype */
@@ -335,6 +410,7 @@ struct ObjectAll{ /* SENDOBJALL */
   short level;
   float experience;
   int kills;        /*number of enemies killed */
+  int ntravels;     /*number of planets landed. */
 
   int durable;
   int visible;      /* not used */
@@ -342,14 +418,14 @@ struct ObjectAll{ /* SENDOBJALL */
   int radar;        /* radar range */
   int mass;         /* mass */
 
-  int cargo;        /* capacity of the bodega TODO*/
+  unsigned int items;
   int radio;        /* ship radio */
   float cost;       /* cost of the object per unit time*/
   int damage;       /* damage of the ship in collision*/
 
   short ai;         /* -1: by keyboard. [0,10] */
   short modified;   /* SENDOBJMOD, SENDOBJMOD0, etc, must be updated by net */
-  short ttl;        /* if !=0 dont send  */
+  short ttl;        /* if !=0 don't send  */
   short habitat;    /* free space or planet (H_SPACE H_PLANET)*/
   short mode;       /* LANDED, NAV(EGATING)  */
 
@@ -370,82 +446,72 @@ struct ObjectAll{ /* SENDOBJALL */
   float state;      /* estate of the ship %[0,100]*/
 
   float dest_r2;    /* distance**2 to the nearest object */
-  int sw;
+  int sw;           /* id of his killer */
   short trace;
  
   int norder;       /* number of pending orders */
-  struct Order actorder;
+  struct Order actorder;  /* actual order */
 
-  int parent;     /* pointer to parent obj */
-  int dest;       /* pointer to nearest enemy object */
-  int in;         /* Object in which is contained */ 
+  int parent;       /* pointer to parent obj */
+  int dest;         /* pointer to nearest enemy object */
+  int inid;         /* Object in which is contained */ 
 
-  int weapon;     /*weapon selected 0 1 2*/
-  Weapon weapon0;     /* actual weapon */
-  Weapon weapon1;     /* actual weapon */
-  Weapon weapon2;     /* actual weapon */
-  Engine engine;      /* motor */
+  int weapon;        /*weapon selected 0 1 2*/
+  Weapon weapon0;    /* actual weapon */
+  Weapon weapon1;    /* actual weapon */
+  Weapon weapon2;    /* actual weapon */
+  Engine engine;     /* motor */
+  Cargo cargo;        /* capacity of the dock TODO */
 };
 
-
-
-
-struct ObjectNew{ /* SENDOBJNEW */
-  int id;         /* identificador */
-  /*  char name[OBJNAMESMAXLEN];*/ /*    object name  */
+struct ObjectNew{   /* SENDOBJNEW */
+  int id;           /* identificador */
   short player;
   short type;       /* type: SHIP,PLANET,PROJECTILE,... */
 
   short subtype;    /* subtipo de objeto */
-  /*  int level; */
-  /*  float experience; */
-  /*  int points; */
-
   int durable;
-  int radio;      /* ship radio */
-  int damage;     /* damage of the ship */
+  int radio;        /* ship radio */
+  int damage;       /* damage of the ship */
 
   short ai;         /* -1: by keyboard. [0,10] */
   short modified;   /* SENDOBJMOD, SENDOBJMOD0, etc, must be updated by net */
   short habitat;    /* free space or planet (H_SPACE H_PLANET)*/
   short mode;       /* LANDED, NAV(EGATING)  */
 
-  float x,y;      /* position */
-  float vx,vy;    /* velocity */
+  float x,y;        /* coordinates */
+  float vx,vy;      /* velocity */
+  float a;          /* ship angle */
+  float gas;        /* gas */
+  float life;       /* time life */
 
-  float a;        /* ship angle */
-  float gas;      /* gas */
-  float life;     /* time life */
-
-  int parent;     /* pointer to parent obj */
-  int in;         /* Object in which is contained */ 
+  int parent;       /* pointer to parent obj */
+  int inid;         /* Object in which is contained */ 
   int planet;
 
   int engtype;
 };
 
 
-
 struct ObjectAAll{  /* SENDOBJAALL */
-  int id;         /* identificador */
+  int id;           /* identificador */
   short level;
-
-  short habitat;    /* free space or planet */
+  short habitat;    /* free space, planet or ship */
   short mode;       /* LANDED, NAVEGATING  */
-  float x,y;      /* posicion actual */
-  float x0,y0;    /* posicion anterior */  
-  float vx,vy;    /* velocidad actual */  
+  float x,y;        /* actual coordinates */
+  float x0,y0;      /* old coordinates  */  
+  float vx,vy;      /* actual velocity */  
 
-  float a;        /* angulo nave */
-  float ang_v;    /* velocidad angular */
-  float ang_a;    /* angular acceleration */
-  float accel;     /* aceleracion */
+  float a;          /* ship angle */
+  float ang_v;      /* angular velocity */
+  float ang_a;      /* angular acceleration */
+  float accel;      /* acceleration */
 
-  float gas;      /* combustible */
-  float life;     /* tiempo de vida */
-  float state;    /* estado de la nave %[0,100]*/
+  float gas;        /* fuel */
+  float life;       /* life time */
+  float state;      /* ship state %[0,100]*/
 
-  int in;         /* Object in which is contained */ 
+  int inid;         /* Object id in which is contained */ 
 };
 
 
@@ -453,21 +519,22 @@ struct Objectdynamic{ /* SENDOBJMOD */
   int id;          /* identificador */
   short level;
   short habitat;   /* free space or planet */
+  int inid;        /* id of the container */
   short mode;      /* LANDED, NAVEGATING  */
-  float x,y;       /* posicion actual */
-  float x0,y0;     /* posicion anterior */   
-  float vx,vy;     /* velocidad actual */ 
-  float a;         /* angulo nave */
-  float ang_v;     /* velocidad angular */
+  float x,y;       /* actual coordinates */
+  float x0,y0;     /* old coordinates */   
+  float vx,vy;     /* actual velocity */ 
+  float a;         /* ship angle */
+  float ang_v;     /* angular velocity */
   float ang_a;     /* angular acceleration */
-  float accel;     /* aceleracion */
-
-  float state;     /* estado de la nave %[0,100]*/
+  float accel;     /* aceleration */
+  float state;     /* ship state %[0,100]*/
 };
 
-struct Objectpos{  /* SENDOBJMOD0 */
-  int id;         /* identificador */
-  float x,y;      /* posicion actual */
+
+struct Objectpos{   /* SENDOBJMOD0 */
+  int id;           /* identificador */
+  float x,y;        /* actual coordinates */
 };
 
 struct NearObject{
@@ -475,134 +542,41 @@ struct NearObject{
   float d2;
 };
 
-struct ObjList{
-  Object *obj;
-  struct ObjList *next;
-};
-
-struct HeadObjList{
-  int n;
-  struct ObjList *next;
-};
-
-struct ObjTree{
-  Object *obj;
-  struct ObjTree *next;
-  struct ObjTree *in;
-};
-
-struct VerletList{
-  Object *obj;
-  struct ObjList *nextobj;
-  struct VerletList *next;
-};
-
 
 struct Habitat{
   int type;      /* H_SPACE, H_PLANET , H_SHIP */
   Object *obj;
 };
 
-struct Global{
-  int actual_player;
-  int g_objid,g_projid;
-  int ship_c,cv;
-  int habitat_type;
-  int habitat_id;
-  int fobj[4];
-};
-
-struct Player{
-  char playername[PLAYERNAMEMAXLEN]; /* name of the player */
-  short id;          /* player id */
-  int pid;         /* last ship player id  */
-  short proc;        /* machine that controls it */
-  short control;     /* HUMAN or COMPUTER */
-  short team;        /* each player belongs to a team */
-  short profile;     /* */
-  short strategy;    /* */
-  short maxlevel;    /* max ship level reached */
-  int color;       /*    */
-  int cv;          /* id of the actual ship */
-  int nplanets;    /* number of players planets */
-  int nships;      /* number of players ships */
-  int nbuildships; /* number of ships created */
-  float gold;      /* actual gold of the player */ 
-  float balance;
-  int lastaction;  /* buy or upgrade */
-  int ndeaths;     /* number of casualties */
-  int nkills;      /* number of enemies killed  */
-  int points;      /*  */
-  short modified;    /* used in communication */
-  short ttl;
-
-  struct IntList *kplanets;
-  struct HeadIntIList ksectors;
-};
-
-struct PlayerAll{
-  char playername[PLAYERNAMEMAXLEN]; /* name of the player */
-  short id;          /* player id */
-  int pid;         /* last ship player id  */
-  short proc;        /* machine that controls it */
-  short control;     /* HUMAN or COMPUTER */
-  short team;        /* each player belongs to a team */
-  short profile;     /* */
-  short strategy;    /* */
-  short maxlevel;    /* max ship level reached */
-  int color;       /*    */
-  int cv;          /* id of the actual ship */
-  int nplanets;    /* number of players planets */
-  int nships;      /* number of players ships */
-  int nbuildships; /* number of ships created */
-  float gold;      /* actual gold of the player */ 
-  float balance;
-  int lastaction;  /* buy or upgrade */
-  int ndeaths;     /* number of casualties */
-  int nkills;      /* number of enemies killed  */
-  int points;      /*  */
-  short modified;    /* used in communication */
-  short ttl;
-};
-
-
-
-struct PlayerMod{  /* Used in communication  */
-  short id;
-  short nplanets;    /* number of players planets */
-  short nships;      /* number of players ships */
-  short nbuildships; /* number of ships created */
-  float gold;      /* actual gold of the player */ 
-  short ndeaths;     /* number of casualties */
-  short nkills;      /* number of enemies killed  */
-  int points;      /*  */
-};
 
 
 /* function Declarations */
 
 int CopyObject(Object *obj,Object *nobj);
 void Experience(Object *obj,float points);
-Object *NewObj(struct HeadObjList *lhobjs,int type,int stype,
+Object *NewObj(int type,int stype,
 	       int x,int y,float vx,float vy,
 	       int weapontype,int engtype,int,Object *parent,Object *in);
+void ShipProperties(Object *obj,int stype,Object *in);
 void NewWeapon(Weapon *weapon,int type);
 void NewEngine(Engine *eng,int type);
 struct Planet *NewPlanet(void);
-int GetSegment(Segment *segment,Object *obj);
+/* int GetSegment(Segment *segment,Object *obj); */
+int GetSegment(Segment *segment,struct Planet *planet,float x,float y);
 int GetLandedZone(Segment *segment,struct Planet *planet);
 
 Object *RemoveDeadObjs(struct HeadObjList *lhobjs,Object *);
 void RemoveObj(struct HeadObjList *lhobjs,Object *obj2remove);
+int GameOver(struct HeadObjList *lhead,struct Player *players,int actual_player);
 
 int CountObjs(struct HeadObjList *lh,int player,int type,int subtype);
-int CountShipsInPlanet(struct HeadObjList *lh,int planetid,int type,int subtype,int max);
+int CountShipsInPlanet(struct HeadObjList *lh,int planetid,int player,int type,int subtype,int max);
+int CountShips(struct HeadObjList *lh,int *c,int *s);
 int CountPlayerShipObjs(struct HeadObjList *lh,int player,int *cont);
-int CountPlayerPlanets(struct HeadObjList *lh,struct Player player,int *cont);
+int CountPlayerPlanets(struct HeadObjList *lh,struct Player *player,int *cont);
 int CountPlanets(struct HeadObjList *lh,int type);
 int CountModObjs(struct HeadObjList *lh,int type);
 
-
 void PrintObj(Object *obj);
 
 Object *SelectObj(struct HeadObjList *lh,int id);
@@ -616,11 +590,13 @@ Object *FirstShip(struct HeadObjList *lh,Object *cv0,int pid);
 Object *NextPlanetCv(struct HeadObjList *lh,Object *cv0,int pid);
 Object *PrevPlanetCv(struct HeadObjList *lh,Object *cv0,int pid);
 
-void Explosion(struct HeadObjList *lh,Object *obj);
+void Explosion(struct HeadObjList *lh,Object *cv,Object *obj,int type);
 
+Object *ObjNearThan(struct HeadObjList *lh,int player,int x,int y,float dmin2);
+float Distance2NearestShip(struct HeadObjList *lh,int player,int x,int y);
+float Distance2NearestShipLessThan(struct HeadObjList *lh,int player,int x,int y,float dmin);
 void NearestObjAll(struct HeadObjList *lhc,Object *obj,struct NearObject *objs);
-Object *NearestObj(struct HeadObjList *lh,Object *obj,int type,int status,float *d2);
-int NearestObjs(struct HeadObjList *lh,Object *obj,int type,int status,int n,struct NearObject *objs);
+Object *NearestObj(struct HeadObjList *lh,Object *obj,int type,int stype,int status,float *d2);
 
 void DestroyAllObj(struct HeadObjList *lh);
 void DestroyObj(Object *obj);
@@ -630,6 +606,8 @@ void DestroyPlanet(struct Planet *planet);
 int Add2TextMessageList(struct TextMessageList *lh,char *cad,int source,int dest,int mid,int time,int value);
 
 int Add2ObjList(struct HeadObjList *lhobjs,Object *obj);
+int Add2ObjList_B(struct HeadObjList *lhobjs,Object *obj);
+int Add2ObjList_E(struct HeadObjList *lhobjs,Object *obj);
 int DestroyObjList(struct HeadObjList *lh);
 int CountObjList(struct HeadObjList *hlist);
 int PrintObjList(struct HeadObjList *hl);
@@ -642,41 +620,58 @@ int CreateContainerLists(struct HeadObjList *lh,struct HeadObjList *hcontainer);
 int CreatekplanetsLists(struct HeadObjList *lh,struct HeadObjList *hkplanets);
 int CreatePlanetList(struct HeadObjList,struct HeadObjList *);
 void CreateNearObjsList(struct HeadObjList *lh,struct HeadObjList *lhn,int player);
+int CreatePilot(Object *obj);
 
-
-int Add2TextList(struct TextList *head,char *cad,int color);
-int DestroyTextList(struct TextList *head);
-int PrintTextList(struct TextList *head);
-int PosTextList(struct TextList *head,int m);
-int CountTextList(struct TextList *head);
 char Type(Object *obj);
-
-
-int Cuadrante(float x, float y);
-void InvCuadrante(int n,int *x, int *y);
-int NearestSector(struct HeadIntIList *head,float a,float b);
-int NearRandomSector(struct HeadIntIList *head,float a,float b);
+char *TypeCad(Object *obj);
 
 int UpdateSectors(struct HeadObjList lh);
 int GetPrice(Object *obj,int sid,int eng,int weapon);
-int BuyShip(struct Player player,Object *obj,int type);
+int BuyShip(struct Player *player,Object *obj,int type);
 
 
-Object *MarkObjs(struct HeadObjList *lh,Region reg);
-int UnmarkObjs(struct HeadObjList *lh);
+Object *MarkObjs(struct HeadObjList *lh,Space reg,Object *cv,int ctrl);
+void UnmarkObjs(struct HeadObjList *lh);
 int PrintSelected(struct HeadObjList *lh);
-int CountSelected(struct HeadObjList *lh);
+int CountSelected(struct HeadObjList *lh,int player);
+int CountNSelected(struct HeadObjList *lh,int player);
 int NearMaxLevelObj(Object *obj,struct HeadObjList *lh);
-int PlanetEmpty(Object *planet,Object *obj);
+int IsPlanetEmpty(Object *planet,Object *obj);
+Object *FirstSelected(struct HeadObjList *lh,int player);
+Object *SelectOneShip(struct HeadObjList *lh,Space region,Object *cv,int ctrl);
+
+int IsInRegion(Object *obj,Space region);
 
 
 int UpdateCell(struct HeadObjList *lh,int *cell);
-int ValueCell(int *cell,Object *obj);
+int ValueCell(int *cell,Object *obj,int x,int y);
 
+int CreatePilot( Object *obj);
+
+
+
+float Distance2(Object *obj1,Object *obj2);
+float Distance(Object *cv,float x0,float y0);
+
+int CheckObjsId(void);
+
+
+int CargoAdd(Object *obj1,Object *obj2);
+int CargoRem(Object *obj1,Object *obj2);
+int CargoDestroy(Object *obj);
+void CargoCheck(struct HeadObjList *hol,Object *);
+int CargoEjectObjs(Object *obj,int type,int subtype);
+Object *CargoGet(Object *obj1,int type,int subtype);
+int CargoIsObj(Object *obj,Object *obj2);
+int CargoPrint(Object *obj);
+int CargoGetMass(Object *obj);
+int CargoBuild(Object *obj);
 
 
 /*************************/
-
+/*****************************************************************/
+/*  Obj Tree. Verlet lists. NOT USED  */
+/*****************************************************************/
 struct ObjTree *Add2ObjTree(struct ObjTree *,Object *);
 struct ObjTree *DelObjTree(struct ObjTree *head,Object *obj);
 void DestroyTree(struct ObjTree *head);
@@ -684,11 +679,8 @@ void PrintObjTree (struct ObjTree *);
 int IsInObjTree(struct ObjTree *,int );
 struct ObjTree *Look4ObjTree(struct ObjTree *,Object *);
 
-
 struct VerletList *CreateVerletList(struct HeadObjList hol);
 void PrintVerletList(struct VerletList *hvl);
 void DestroyVerletList(struct VerletList *hvl);
 
-
-
 #endif
